==> node-v20.12.1.tar.xz: node-v20.12.1/doc/contributing/sharing-project-news.md <==
# Sharing project news

The project aims to make it easy
to share project news with those who publish newsletters
that cover Node.js.

The project's approach is as follows:

* The project will create one "What's new in YYYY" discussion item in
  the `nodejs/node` repo for news related to Node.js core.
* Teams/groups can create a "what's new in YYYY" issue or discussion item
  in one or more of their repositories. As an example see
  [What's new in the Node-API and node-addon-api world? - 2023 version](https://github.com/nodejs/abi-stable-node/issues/446).
* Collaborators periodically add news as additional comments on these
  issues throughout the year.
* At the end of each year the issue is closed and if appropriate a
  new one is created.
* A list of these documents is maintained in the section below as a
  quick way to find them.
* The next-10 team reaches out to teams/groups on an ad hoc basis
  to ensure teams know about the option for sharing news.
* The next-10 team reaches out to those who publish newsletters ad hoc
  to let them know about this approach and how they can find the updates.

We trust/expect collaborators to post project related news versus news
that promotes a specific company or commercial interest.

## Teams doing updates

* [Node.js core](https://github.com/orgs/nodejs/discussions/47703).
* [node-api/node-addon-api](https://github.com/nodejs/abi-stable-node/issues/459).
* [uvwasi](https://github.com/nodejs/uvwasi/issues/201).
* [security-team](https://github.com/nodejs/security-wg/issues/1006).
* [Website team](https://github.com/nodejs/nodejs.org/issues/5602).
* [diagnostics team](https://github.com/nodejs/diagnostics/issues/619).

==> node-v22.21.0.tar.xz: node-v22.21.0/doc/contributing/sharing-project-news.md <==
# Sharing project news

The project aims to make it easy
to share project news with those who publish newsletters
that cover Node.js.

The project's approach is as follows:

* The project will create one "What's new in YYYY" discussion item in
  the `nodejs/node` repo for news related to Node.js core.
* Teams/groups can create a "what's new in YYYY" issue or discussion item
  in one or more of their repositories. As an example see
  [What's new in the Node-API and node-addon-api world? - 2023 version](https://github.com/nodejs/abi-stable-node/issues/446).
* Collaborators periodically add news as additional comments on these
  issues throughout the year.
* At the end of each year the issue is closed and if appropriate a
  new one is created.
* A list of these documents is maintained in the section below as a
  quick way to find them.
* The next-10 team reaches out to teams/groups on an ad hoc basis
  to ensure teams know about the option for sharing news.
* The next-10 team reaches out to those who publish newsletters ad hoc
  to let them know about this approach and how they can find the updates.

We trust/expect collaborators to post project related news versus news
that promotes a specific company or commercial interest.

## Teams doing updates

* [node-api/node-addon-api](https://github.com/nodejs/abi-stable-node/issues/459).
* [uvwasi](https://github.com/nodejs/uvwasi/issues/201).
* [Website team](https://github.com/nodejs/nodejs.org/issues/5602).
* [diagnostics team](https://github.com/nodejs/diagnostics/issues/619).
* [ambassadors](https://github.com/nodejs/nodejs-ambassadors/issues/2).
